import { FormControl } from '@angular/forms';
import { CdkDragDrop } from '@angular/cdk/drag-drop';
import { ActivatedRoute, Router } from '@angular/router';
import { StoreBuilderService } from '../../services/store-builder.service';
import { HeaderFilter } from '../../interfaces/layout-builder.interface';
import { NgbModal, NgbOffcanvas } from '@ng-bootstrap/ng-bootstrap';
import { ChangeDetectorRef, ElementRef, OnDestroy, OnInit, Renderer2 } from '@angular/core';
import { ToastService } from 'tango-app-ui-shared';
import * as i0 from "@angular/core";
export declare class CreateLayoutComponent implements OnInit, OnDestroy {
    private cd;
    private renderer;
    private route;
    private apiService;
    private router;
    private offcanvasService;
    private toastService;
    private modalDef;
    floorsInput: FormControl<any>;
    canvasRef: ElementRef<HTMLCanvasElement>;
    widgetCanvasRef: ElementRef<HTMLCanvasElement>;
    scrollContainerRef: ElementRef;
    gridWidth: number;
    gridHeight: number;
    private ctx;
    private canvas;
    private widgetCtx;
    private widgetCanvas;
    elementType: 'wall' | 'facade' | 'opening' | 'entrance';
    layoutPolygon: any[];
    popupVisible: boolean;
    popupPosition: any;
    selectedLine: any;
    selectedLineIndex: number | null;
    movePixels: number;
    moveAngle: number;
    unit: 'ft';
    moveDirection: 'left' | 'right' | 'up' | 'down';
    layoutMode: 'full' | 'half';
    elementSelect: {
        show: boolean;
        index: number;
    };
    directionSelect: {
        show: boolean;
        index: number;
    };
    lineOptionsSelect: {
        show: boolean;
        index: number;
    };
    widgetElementSelect: {
        show: boolean;
    };
    layoutOptionSelect: {
        show: boolean;
    };
    floorSelect: {
        show: boolean;
        deleteIndex: number | null;
    };
    private scale;
    panOffset: {
        x: number;
        y: number;
    };
    breakpoints: number[];
    circleRef: ElementRef;
    pointerRef: ElementRef;
    lines: {
        transform: string;
        highlight: boolean;
        invisible: boolean;
    }[];
    private minAngle;
    private maxAngle;
    private destroy$;
    headerData: HeaderFilter | null | undefined;
    planoStoreList: any[];
    selectedStore: any;
    selectedFloor: any;
    undoStack: any[];
    redoStack: any[];
    planoIds: string[];
    itemsPerPage: number;
    currentPage: number;
    totalItems: number;
    paginationSizes: number[];
    pageSize: number;
    pixelPerMetre: number;
    cumulativeRotation: number;
    onPageChange(val: number): void;
    saveStateToUndo(): void;
    undo(): void;
    redo(): void;
    constructor(cd: ChangeDetectorRef, renderer: Renderer2, route: ActivatedRoute, apiService: StoreBuilderService, router: Router, offcanvasService: NgbOffcanvas, toastService: ToastService, modalDef: NgbModal);
    initializeLayout(): void;
    ngOnInit(): void;
    onFloorSelect(floorId: string): void;
    ngOnDestroy(): void;
    onStoreChange(event: any): void;
    openOffCanva(): void;
    getPlanoData(): void;
    updateFloorLayout(): void;
    deleteFloor(index: number): void;
    addFloor(planoId: string, floorCount: number): void;
    onSaveAsDraft(): void;
    onConfigure(): void;
    drawWidgetRing(): void;
    private updateWidgetPointer;
    drawGrid(): void;
    drawPolygon(polygon?: any[]): void;
    onMouseWheel(event: WheelEvent): void;
    adjustZoom(event: MouseEvent, scaleFactor: number): void;
    resetZoom(): void;
    transformPoint(point: {
        x: number;
        y: number;
    }): {
        x: number;
        y: number;
    };
    drawLine(ctx: CanvasRenderingContext2D, line: {
        x: number;
        y: number;
    }[]): void;
    redrawCanvas(): void;
    onOutsideClick(event: MouseEvent): void;
    toggleLineOptionsSelect(index: number): void;
    toggleDirectionSelect(index: number): void;
    toggleElementSelect(index: number): void;
    toggleWidgetElementSelect(): void;
    toggleLayoutOptionSelect(): void;
    toggleFloorSelect(): void;
    drop(event: CdkDragDrop<any[]>): void;
    snapToGrid(value: number, gridSize: number): number;
    isPointInPolygon(point: any, polygon: any[]): boolean;
    movePointWithAngle(): void;
    getMaxElementNumber(data: any, elementType: string): number;
    onMouseDown(event: MouseEvent): void;
    selectLine(line: any, index: number): void;
    openWidget(position: {
        x: number;
        y: number;
    }, offset?: {
        up: number;
        right: number;
        down: number;
        left: number;
    }): void;
    closeWidget(): void;
    onMouseMove(event: MouseEvent): void;
    drawLineWithLength(start: any, end: any): void;
    layoutLengthPreview(): void;
    rotatePolygons(): void;
    resetOrientation(): void;
    isLineEqual(start1: {
        x: number;
        y: number;
    }, end1: {
        x: number;
        y: number;
    }, start2: {
        x: number;
        y: number;
    }, end2: {
        x: number;
        y: number;
    }, tolerance: number): boolean;
    convertToPixels(value: number, unit: 'ft' | 'm'): number;
    onElementTypeChange(type: string, index: number): void;
    onDistanceChange(value: 'increment' | 'decrement', index: number): void;
    onWidgetDistanceChange(value: 'increment' | 'decrement'): void;
    onWidgetAngleChange(value: 'increment' | 'decrement'): void;
    onWidgetDirectionChange(direction: 'left' | 'right' | 'up' | 'down'): void;
    onDirectionChange(value: 'up' | 'left' | 'down' | 'right', index: number): void;
    onLineDelete(index: number): void;
    onAddStep(index: number): void;
    onDuplicateStep(index: number): void;
    scrollToCanvasPosition(coordinates: {
        x: number;
        y: number;
    }): void;
    onClearAll(): void;
    onDeleteLayout(): void;
    exportAsPng(): Promise<void>;
    generateLayoutPolygon(layoutInstructions: any): void;
    normalizedPixelPerMetre(polygon: any): number;
    isFloorCompleted(layoutInstructions: any, thresholdInFeet?: number): boolean;
    validateAngleInput(event: Event, index: number): void;
    onAngleChange(index: number): void;
    openAddFloorModal(): void;
    findPolygonCenterAndScroll(polygon?: any): void;
    exportToExcel(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<CreateLayoutComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<CreateLayoutComponent, "lib-create-layout", never, {}, {}, never, never, false, never>;
}
